__version__ = "0.6.47"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(HEAD detached at v0.6.47)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '550ab122ce91cb682e8e172a9ef72034b5a95dda'
__git_head_subject__ = 'Finished Release v0.6.47'
__git_head_message__ = ''
__git_dirty_diff__ = ''
__git_commit_date__ = '2016-06-22 15:45:50'
